carp_backend library

Classes

CarpDataEndPoint
Specify a CARP Web Service (CAWS) endpoint for uploading data.
CarpDataManager
Upload CAMS measurement to the CARP Web Services (CAWS) backend.
CarpDataManagerEventTypes
An enumeration of file data manager event types
CarpDataManagerFactory
CarpLocalizations
A Localization implementation that support loading localization from the CARP web service.
CarpResourceManager
Implementation of InformedConsentManager, LocalizationManager, and MessageManager in the CARP services (CAWS) API.
DataStreamBuffer
A local buffer of data streams using the SQLiteDataManager. Works as a singleton accessed by DataStreamBuffer(), since it is backed by a single, app-wide carp-data.db file.
InformedConsentManager
Handles retrieving and storing consent document definitions as RPOrderedTask json definitions.
LocalizationManager
Handles retrieving and storing language localization mappings.
Message
A message to be shown in the message list
MessageManager

Enums

CarpUploadMethod
A enumeration of upload methods to CAWS
MessageType
The different types of messages that can occur in the list of messages

Exceptions / Errors

CarpBackendException
Exception for CAWS communication.